1.0.0 API documentation: GLM_GTX_handed_coordinate_space

| 1.0.0 API documentation

Functions
GLM_GTX_handed_coordinate_space
Experimental extensions

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | leftHanded (vec< 3, T, Q > const &tangent, vec< 3, T, Q > const &binormal, vec< 3, T, Q > const &normal)
| Return if a trihedron left handed or not. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL bool | rightHanded (vec< 3, T, Q > const &tangent, vec< 3, T, Q > const &binormal, vec< 3, T, Q > const &normal)
| Return if a trihedron right handed or not. More...

## Detailed Description

Include <glm/gtx/handed_coordinate_space.hpp> to use the features of this extension.

To know if a set of three basis vectors defines a right or left-handed coordinate system.

## Function Documentation

## ◆ leftHanded()

GLM_FUNC_DECL bool glm::leftHanded | ( | vec< 3, T, Q > const & | tangent,
|  | vec< 3, T, Q > const & | binormal,
|  | vec< 3, T, Q > const & | normal
| ) |  |

Return if a trihedron left handed or not.

From GLM_GTX_handed_coordinate_space extension.

## ◆ rightHanded()

GLM_FUNC_DECL bool glm::rightHanded | ( | vec< 3, T, Q > const & | tangent,
|  | vec< 3, T, Q > const & | binormal,
|  | vec< 3, T, Q > const & | normal
| ) |  |

Return if a trihedron right handed or not.

From GLM_GTX_handed_coordinate_space extension.